@@ -55,17 +55,22 @@ class ModelMeta(DeclarativeMeta):
         if not dct.get('__events__'):
             dct['__events__'] = {}
 
+        if '__bind_key__' not in dct:
+            for base in base_dcts:
+                if '__bind_key__' in base:
+                    dct['__bind_key__'] = base['__bind_key__']
+                    break
+
         return DeclarativeMeta.__new__(mcs, name, bases, dct)
 
     def __init__(cls, name, bases, dct):
-        bind_key = dct.pop('__bind_key__', None)
-
         DeclarativeMeta.__init__(cls, name, bases, dct)
 
-        if bind_key is not None:
-            cls.__table__.info['bind_key'] = bind_key
+        if hasattr(cls, '__table__'):
+            if '__bind_key__' in dct:
+                cls.__table__.info['bind_key'] = dct['__bind_key__']
 
-        events.register(cls, dct)
+            events.register(cls, dct)
 
 
 class ModelBase(object):
